==> business_proxy-tomato.20190129.024156-99-sources.jar: com/jz/jar/business/card/ItemCard.java <==
package com.jz.jar.business.card;

import com.jz.jar.business.enums.CardType;
import com.jz.jar.business.wrapper.ActivityWrapper;
import com.jz.jar.business.wrapper.CommentWrapper;
import com.jz.jar.business.wrapper.LessonFeedbackWrapper;
import com.jz.jar.business.wrapper.LessonWrapper;
import com.jz.jar.business.wrapper.LevelWrapper;
import com.jz.jar.business.wrapper.NewsInfoWrapper;
import com.jz.jar.business.wrapper.PlaylistWrapper;
import com.jz.jar.business.wrapper.SysNotifyWrapper;
import com.jz.jar.business.wrapper.TopicWrapper;
import com.jz.jar.business.wrapper.UserNoticeWrapper;
import com.jz.jar.business.wrapper.VideoWrapper;
import com.jz.jar.business.wrapper.WorksInfoWrapper;
import com.jz.jar.business.wrapper.WorksThemeWrapper;

/**
 * @Title ItemCard
 * @Package com.jz.jar.media.common
 * @author tangjunfeng
 * @date 2018年8月3日 下午6:35:46
 * @version V1.0
 */
public class ItemCard {
	private ItemCard() {
	}

	private ItemCard(CardType type) {
		this.type = type;
	}

	private CardType type;

	private VideoWrapper video;
	private PlaylistWrapper playlist;
	private LevelWrapper level;
	private TopicWrapper topic;
	private UserNoticeWrapper notice;
	private LessonWrapper lesson;
	private LessonFeedbackWrapper lessonFb;
	private CommentWrapper comment;
	private WorksInfoWrapper works;
	private WorksThemeWrapper theme;
	private SysNotifyWrapper sysNotify;
	private NewsInfoWrapper news;
	private ActivityWrapper activity;

	public static ItemCard of() {
		return new ItemCard();
	}

	public static ItemCard of(VideoWrapper video) {
		return new ItemCard(CardType.video).setVideo(video);
	}

	public static ItemCard of(PlaylistWrapper playlist) {
		return new ItemCard(CardType.playlist).setPlaylist(playlist);
	}

	public static ItemCard of(LevelWrapper level) {
		return new ItemCard(CardType.level).setLevel(level);
	}

	public static ItemCard of(TopicWrapper topic) {
		return new ItemCard(CardType.topic).setTopic(topic);
	}

	public static ItemCard of(UserNoticeWrapper notice) {
		return new ItemCard(CardType.notice).setNotice(notice);
	}

	public static ItemCard of(LessonWrapper lesson) {
		return new ItemCard(CardType.lesson).setLesson(lesson);
	}

	public static ItemCard of(LessonFeedbackWrapper lessonFb) {
		return new ItemCard(CardType.lessonFb).setLessonFb(lessonFb);
	}

	public static ItemCard of(CommentWrapper comment) {
		return new ItemCard(CardType.comment).setComment(comment);
	}

	public static ItemCard of(WorksInfoWrapper works) {
		return new ItemCard(CardType.works).setWorks(works);
	}

	public static ItemCard of(WorksThemeWrapper theme) {
		return new ItemCard(CardType.theme).setTheme(theme);
	}

	public static ItemCard of(SysNotifyWrapper notify) {
		return new ItemCard(CardType.sysNotify).setSysNotify(notify);
	}

	public static ItemCard of(NewsInfoWrapper news) {
		return new ItemCard(CardType.news).setNews(news);
	}

	public static ItemCard of(ActivityWrapper activity) {
		return new ItemCard(CardType.activity).setActivity(activity);
	}

	public CardType getType() {
		return type;
	}

	public ItemCard setType(CardType type) {
		this.type = type;
		return this;
	}

	public VideoWrapper getVideo() {
		return video;
	}

	public ItemCard setVideo(VideoWrapper video) {
		this.video = video;
		return this;
	}

	public PlaylistWrapper getPlaylist() {
		return playlist;
	}

	public ItemCard setPlaylist(PlaylistWrapper playlist) {
		this.playlist = playlist;
		return this;
	}

	public LevelWrapper getLevel() {
		return level;
	}

	public ItemCard setLevel(LevelWrapper level) {
		this.level = level;
		return this;
	}

	public TopicWrapper getTopic() {
		return topic;
	}

	public ItemCard setTopic(TopicWrapper topic) {
		this.topic = topic;
		return this;
	}

	public UserNoticeWrapper getNotice() {
		return notice;
	}

	public ItemCard setNotice(UserNoticeWrapper notice) {
		this.notice = notice;
		return this;
	}

	public LessonWrapper getLesson() {
		return lesson;
	}

	public ItemCard setLesson(LessonWrapper lesson) {
		this.lesson = lesson;
		return this;
	}

	public LessonFeedbackWrapper getLessonFb() {
		return lessonFb;
	}

	public ItemCard setLessonFb(LessonFeedbackWrapper lessonFb) {
		this.lessonFb = lessonFb;
		return this;
	}

	public CommentWrapper getComment() {
		return comment;
	}

	public ItemCard setComment(CommentWrapper comment) {
		this.comment = comment;
		return this;
	}

	public WorksInfoWrapper getWorks() {
		return works;
	}

	public ItemCard setWorks(WorksInfoWrapper works) {
		this.works = works;
		return this;
	}

	public WorksThemeWrapper getTheme() {
		return theme;
	}

	public ItemCard setTheme(WorksThemeWrapper theme) {
		this.theme = theme;
		return this;
	}

	public SysNotifyWrapper getSysNotify() {
		return sysNotify;
	}

	public ItemCard setSysNotify(SysNotifyWrapper sysNotify) {
		this.sysNotify = sysNotify;
		return this;
	}

	public NewsInfoWrapper getNews() {
		return news;
	}

	public ItemCard setNews(NewsInfoWrapper news) {
		this.news = news;
		return this;
	}

	public ActivityWrapper getActivity() {
		return activity;
	}

	public ItemCard setActivity(ActivityWrapper activity) {
		this.activity = activity;
		return this;
	}

}

==> business_proxy-tomato.20190129.040628-100-sources.jar: com/jz/jar/business/card/ItemCard.java <==
package com.jz.jar.business.card;

import com.jz.jar.business.enums.CardType;
import com.jz.jar.business.wrapper.ActivityWrapper;
import com.jz.jar.business.wrapper.CommentWrapper;
import com.jz.jar.business.wrapper.LessonFeedbackWrapper;
import com.jz.jar.business.wrapper.LessonWrapper;
import com.jz.jar.business.wrapper.LevelWrapper;
import com.jz.jar.business.wrapper.NewsInfoWrapper;
import com.jz.jar.business.wrapper.NoticeWrapper;
import com.jz.jar.business.wrapper.PlaylistWrapper;
import com.jz.jar.business.wrapper.TopicWrapper;
import com.jz.jar.business.wrapper.VideoWrapper;
import com.jz.jar.business.wrapper.WorksInfoWrapper;
import com.jz.jar.business.wrapper.WorksThemeWrapper;

/**
 * @Title ItemCard
 * @Package com.jz.jar.media.common
 * @author tangjunfeng
 * @date 2018年8月3日 下午6:35:46
 * @version V1.0
 */
public class ItemCard {
	private ItemCard() {
	}

	private ItemCard(CardType type) {
		this.type = type;
	}

	private CardType type;

	private VideoWrapper video;
	private PlaylistWrapper playlist;
	private LevelWrapper level;
	private TopicWrapper topic;
	private NoticeWrapper notice;
	private LessonWrapper lesson;
	private LessonFeedbackWrapper lessonFb;
	private CommentWrapper comment;
	private WorksInfoWrapper works;
	private WorksThemeWrapper theme;
	private NewsInfoWrapper news;
	private ActivityWrapper activity;

	public static ItemCard of() {
		return new ItemCard();
	}

	public static ItemCard of(VideoWrapper video) {
		return new ItemCard(CardType.video).setVideo(video);
	}

	public static ItemCard of(PlaylistWrapper playlist) {
		return new ItemCard(CardType.playlist).setPlaylist(playlist);
	}

	public static ItemCard of(LevelWrapper level) {
		return new ItemCard(CardType.level).setLevel(level);
	}

	public static ItemCard of(TopicWrapper topic) {
		return new ItemCard(CardType.topic).setTopic(topic);
	}

	public static ItemCard of(NoticeWrapper notice) {
		return new ItemCard(CardType.notice).setNotice(notice);
	}
	
	public static ItemCard ofSysNotify(NoticeWrapper notice) {
		return new ItemCard(CardType.sysNotify).setNotice(notice);
	}
	
	public static ItemCard of(LessonWrapper lesson) {
		return new ItemCard(CardType.lesson).setLesson(lesson);
	}

	public static ItemCard of(LessonFeedbackWrapper lessonFb) {
		return new ItemCard(CardType.lessonFb).setLessonFb(lessonFb);
	}

	public static ItemCard of(CommentWrapper comment) {
		return new ItemCard(CardType.comment).setComment(comment);
	}

	public static ItemCard of(WorksInfoWrapper works) {
		return new ItemCard(CardType.works).setWorks(works);
	}

	public static ItemCard of(WorksThemeWrapper theme) {
		return new ItemCard(CardType.theme).setTheme(theme);
	}

	public static ItemCard of(NewsInfoWrapper news) {
		return new ItemCard(CardType.news).setNews(news);
	}

	public static ItemCard of(ActivityWrapper activity) {
		return new ItemCard(CardType.activity).setActivity(activity);
	}

	public CardType getType() {
		return type;
	}

	public ItemCard setType(CardType type) {
		this.type = type;
		return this;
	}

	public VideoWrapper getVideo() {
		return video;
	}

	public ItemCard setVideo(VideoWrapper video) {
		this.video = video;
		return this;
	}

	public PlaylistWrapper getPlaylist() {
		return playlist;
	}

	public ItemCard setPlaylist(PlaylistWrapper playlist) {
		this.playlist = playlist;
		return this;
	}

	public LevelWrapper getLevel() {
		return level;
	}

	public ItemCard setLevel(LevelWrapper level) {
		this.level = level;
		return this;
	}

	public TopicWrapper getTopic() {
		return topic;
	}

	public ItemCard setTopic(TopicWrapper topic) {
		this.topic = topic;
		return this;
	}

	public NoticeWrapper getNotice() {
		return notice;
	}

	public ItemCard setNotice(NoticeWrapper notice) {
		this.notice = notice;
		return this;
	}

	public LessonWrapper getLesson() {
		return lesson;
	}

	public ItemCard setLesson(LessonWrapper lesson) {
		this.lesson = lesson;
		return this;
	}

	public LessonFeedbackWrapper getLessonFb() {
		return lessonFb;
	}

	public ItemCard setLessonFb(LessonFeedbackWrapper lessonFb) {
		this.lessonFb = lessonFb;
		return this;
	}

	public CommentWrapper getComment() {
		return comment;
	}

	public ItemCard setComment(CommentWrapper comment) {
		this.comment = comment;
		return this;
	}

	public WorksInfoWrapper getWorks() {
		return works;
	}

	public ItemCard setWorks(WorksInfoWrapper works) {
		this.works = works;
		return this;
	}

	public WorksThemeWrapper getTheme() {
		return theme;
	}

	public ItemCard setTheme(WorksThemeWrapper theme) {
		this.theme = theme;
		return this;
	}

	public NewsInfoWrapper getNews() {
		return news;
	}

	public ItemCard setNews(NewsInfoWrapper news) {
		this.news = news;
		return this;
	}

	public ActivityWrapper getActivity() {
		return activity;
	}

	public ItemCard setActivity(ActivityWrapper activity) {
		this.activity = activity;
		return this;
	}

}
